@@ -206,6 +206,7 @@ static void report_Header( int i_report )
 /*****************************************************************************
  * PrintPacketTiming for REPORT_UDP
  *****************************************************************************/
+#ifdef HAVE_SYS_SOCKET_H
 #ifdef HAVE_GETTIMEOFDAY
 static mtime_t report_UDPPacketTiming( int32_t i_seqno, int32_t bytes, mtime_t time_prev, mtime_t *time_base )
 {
@@ -238,7 +239,9 @@ static void report_UDPPacketTiming( int32_t i_seqno, int32_t bytes )
     printf( "%d\n", bytes );
 }
 #endif
+#endif
 
+#ifdef HAVE_SYS_SOCKET_H
 #ifdef HAVE_GETTIMEOFDAY
 static mtime_t report_PCRPacketTiming( int i_cc, ts_pid_t *ts_pid,
                     mtime_t i_prev_pcr, mtime_t time_prev, int32_t i_bytes )
@@ -281,7 +284,7 @@ static void report_PCRPacketTiming( int i_cc, ts_pid_t *ts_pid,
 
     /* bitrate since last pcr */
     if( (i_delta > 0) )
-        printf( "%d %lld", i_bytes, (long long int)(i_bytes*8)/i_delta/1000 );
+        printf( "%d %"PRId64"", i_bytes, (long int)(i_bytes*8)/i_delta/1000 );
     else
         printf( "%d 0", i_bytes );
 
@@ -292,6 +295,7 @@ static void report_PCRPacketTiming( int i_cc, ts_pid_t *ts_pid,
     printf( "\n" );
 #endif
 }
+#endif
 
 static void message(dvbpsi_t *handle, const dvbpsi_msg_level_t level, const char* msg)
 {
@@ -460,33 +464,33 @@ static void DumpSubtitleDescriptor(dvbpsi_subtitling_dr_t* p_subtitle_descriptor
  *****************************************************************************/
 static void DumpDescriptors(const char* str, dvbpsi_descriptor_t* p_descriptor)
 {
-  int i;
+    int i;
 
-  while(p_descriptor)
-  {
-    fprintf( stderr, "%s 0x%02x : ", str, p_descriptor->i_tag);
-    switch (p_descriptor->i_tag)
-      {
-      case SYSTEM_CLOCK_DR:
-    DumpSystemClockDescriptor(dvbpsi_DecodeSystemClockDr(p_descriptor));
-    break;
-      case MAX_BITRATE_DR:
-    DumpMaxBitrateDescriptor(dvbpsi_DecodeMaxBitrateDr(p_descriptor));
-    break;
-      case STREAM_IDENTIFIER_DR:
-    DumpStreamIdentifierDescriptor(dvbpsi_DecodeStreamIdentifierDr(p_descriptor));
-    break;
-      case SUBTITLING_DR:
-    DumpSubtitleDescriptor(dvbpsi_DecodeSubtitlingDr(p_descriptor));
-    break;
-      default:
-    fprintf( stderr, "\"");
-    for(i = 0; i < p_descriptor->i_length; i++)
-      fprintf( stderr, "%c", p_descriptor->p_data[i]);
-      fprintf( stderr, "\"\n");
-      }
-    p_descriptor = p_descriptor->p_next;
-  }
+    while(p_descriptor)
+    {
+        fprintf( stderr, "%s 0x%02x : ", str, p_descriptor->i_tag);
+        switch (p_descriptor->i_tag)
+        {
+        case SYSTEM_CLOCK_DR:
+            DumpSystemClockDescriptor(dvbpsi_DecodeSystemClockDr(p_descriptor));
+            break;
+        case MAX_BITRATE_DR:
+            DumpMaxBitrateDescriptor(dvbpsi_DecodeMaxBitrateDr(p_descriptor));
+            break;
+        case STREAM_IDENTIFIER_DR:
+            DumpStreamIdentifierDescriptor(dvbpsi_DecodeStreamIdentifierDr(p_descriptor));
+            break;
+        case SUBTITLING_DR:
+            DumpSubtitleDescriptor(dvbpsi_DecodeSubtitlingDr(p_descriptor));
+            break;
+        default:
+            fprintf( stderr, "\"");
+            for(i = 0; i < p_descriptor->i_length; i++)
+                fprintf( stderr, "%c", p_descriptor->p_data[i]);
+            fprintf( stderr, "\"\n");
+        }
+        p_descriptor = p_descriptor->p_next;
+    }
 }
 
 /*****************************************************************************
@@ -573,17 +577,17 @@ int main(int i_argc, char* pa_argv[])
     int next_option = 0;
 
     int i_fd = -1;
-    int i_mtu = 1316; /* (7 * 188) = 1316 < 1500 network MTU */
 #ifdef HAVE_SYS_SOCKET_H
+    int i_mtu = 1316; /* (7 * 188) = 1316 < 1500 network MTU */
     int i_report = REPORT_UDP; /* REPORT_PCR REPORT_UDP */
     int i_port = 0;
     char *ipaddress = NULL;
-#endif
 #ifdef HAVE_GETTIMEOFDAY
     mtime_t  time_prev = 0;
     mtime_t  time_base = 0;
 #endif
     mtime_t  i_prev_pcr = 0;  /* 33 bits */
+#endif
     int      i_old_cc = -1;
     uint32_t i_bytes = 0; /* bytes transmitted between PCR's */
     char *filename = NULL;
@@ -636,12 +640,15 @@ int main(int i_argc, char* pa_argv[])
         }
     } while( next_option != -1 );
 
-#ifdef HAVE_SYS_SOCKET_H
     if( b_verbose )
     {
+#ifdef HAVE_SYS_SOCKET_H
         fprintf( stderr, "set mtu to %d\n", i_mtu );
-    }
+#else
+        fprintf( stderr, "using file: %s", filename);
 #endif
+    }
+
     /* initialize */
     if( filename )
     {
@@ -665,6 +672,13 @@ int main(int i_argc, char* pa_argv[])
         goto error;
     }
 
+    if( i_fd < 0 )
+    {
+        fprintf( stderr, "no input selected\n" );
+        usage( pa_argv[0] );
+        goto error;
+    }
+
     p_stream = (ts_stream_t *) malloc( sizeof(ts_stream_t) );
     if( !p_stream )
         goto out_of_memory;
@@ -691,8 +705,9 @@ int main(int i_argc, char* pa_argv[])
     while( i_len > 0 )
     {
         int i = 0;
+#ifdef HAVE_SYS_SOCKET_H
         vlc_bool_t b_first = VLC_FALSE;
-
+#endif
         i_bytes += i_len;
         for( i = 0; i < i_len; i += 188 )
         {
@@ -770,10 +785,11 @@ int main(int i_argc, char* pa_argv[])
                               ( (mtime_t)p_tmp[8] << 9 ) |
                               ( (mtime_t)p_tmp[9] << 1 ) |
                               ( (mtime_t)p_tmp[10] >> 7 ) ) / 90;
-                    i_prev_pcr = p_stream->pid[i_pid].i_pcr;
                     p_stream->pid[i_pid].i_pcr = i_pcr;
 
 #ifdef HAVE_SYS_SOCKET_H
+                    i_prev_pcr = p_stream->pid[i_pid].i_pcr;
+
                     if( i_report == REPORT_PCR )
                     {
 #ifdef HAVE_GETTIMEOFDAY
@@ -849,7 +865,7 @@ out_of_memory:
     fprintf( stderr, "Out of memory\n" );
 
 dvbpsi_out:
-    if( p_stream->pat.handle )
+    if( p_stream && p_stream->pat.handle )
     {
         dvbpsi_pat_detach( p_stream->pat.handle );
         dvbpsi_delete( p_stream->pat.handle );
