@@ -1,7 +1,7 @@
 /*****************************************************************************
  * dvbinfo.c: DVB PSI Information
  *****************************************************************************
- * Copyright (C) 2010-2011 M2X BV
+ * Copyright (C) 2010-2014 M2X BV
  *
  * Authors: Jean-Paul Saman <jpsaman@videolan.org>
  *
@@ -22,6 +22,14 @@
 
 #include "config.h"
 
+#if __APPLE__
+// In Mac OS X 10.5 and later trying to use the daemon function gives a “‘daemon’ is deprecated”
+// error, which prevents compilation because we build with "-Werror".
+// Since this is supposed to be portable cross-platform code, we don't care that daemon is
+// deprecated on Mac OS X 10.5, so we use this preprocessor trick to eliminate the error message.
+#define daemon yes_we_know_that_daemon_is_deprecated_in_os_x_10_5_thankyou
+#endif
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdbool.h>
@@ -41,7 +49,11 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#include <syslog.h>
+#ifndef WIN32
+#   include <syslog.h>
+#else
+#   define O_NONBLOCK (0) /* O_NONBLOCK does not exist for Windows */
+#endif
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -64,11 +76,18 @@
 #   include "tcp.h"
 #endif
 
+#if __APPLE__
+#undef daemon
+extern int daemon(int, int);
+#endif
+
 #define FIFO_THRESHOLD_SIZE (400 * 1024 * 1024) /* threshold in bytes */
 #define ARRAY_SIZE(x) (sizeof(x) / sizeof((x)[0]))
 
+#ifdef HAVE_SYS_SOCKET_H
 static const int   i_summary_mode[] = { SUM_BANDWIDTH, SUM_TABLE, SUM_PACKET, SUM_WIRE };
 static const char *psz_summary_mode[] = { "bandwidth", "table", "packet", "wire" };
+#endif
 
 /*****************************************************************************
  *
@@ -94,7 +113,7 @@ typedef struct dvbinfo_capture_s
 static void usage(void)
 {
 #ifdef HAVE_SYS_SOCKET_H
-    printf("Usage: dvbinfo [-h] [-d <debug>] [-f|-m| [[-u|-t] -a <mcast_interface> -i <ipaddress:port>] -o <outputfile>\n");
+    printf("Usage: dvbinfo [-h] [-d <debug>] [-f <filename> | -m | -c <bufsize> | [[-u|-t] -a <mcast_interface> -i <ipaddress:port>] -o <outputfile>\n");
     printf("               [-s [bandwidth|table|packet] --summary-file <file> --summary-period <ms>]\n");
 #else
     printf("Usage: dvbinfo [-h] [-d <debug>] [-f|\n");
@@ -118,14 +137,18 @@ static void usage(void)
     printf("                         table  = tables and descriptors\n");
     printf("                         packet = decode packets and print structs\n");
 //    printf("                         wire = print arrival time per packet (wireshark like)\n");
-    printf("      --summary-file   : file to write summary information to (default: stdout)\n");
-    printf("      --summary-period : refresh summary file every n milliseconds (default: 1000ms)\n");
+    printf(" -j | --summary-file   : file to write summary information to (default: stdout)\n");
+    printf(" -p | --summary-period : refresh summary file every n milliseconds (default: 1000ms)\n");
+    printf("\nTuning options: \n");
+    printf(" -c | --capture buffer size : number of bytes in capture buffer (default: %d bytes)\n", FIFO_THRESHOLD_SIZE);
 #endif
     exit(EXIT_FAILURE);
 }
 
 /* Logging */
+#ifndef WIN32
 static int log_level[] = { LOG_ERR, LOG_WARNING, LOG_INFO, LOG_DEBUG };
+#endif
 static const char *psz_level[] = { "ERROR", "WARNING", "INFO", "DEBUG" };
 
 static void libdvbpsi_log(void *data, const int level, const char *format, ...)
@@ -154,9 +177,11 @@ static void libdvbpsi_log(void *data, const int level, const char *format, ...)
         free(msg);
         return;
     }
+#ifndef WIN32
     if (param->b_monitor)
         syslog(log_level[level], "%s", msg);
     else
+#endif
         fprintf(stderr, "%s: %s", psz_level[level], msg);
     free(msg);
 }
@@ -177,6 +202,9 @@ static params_t *params_init(void)
     param->b_verbose = false;
     param->b_monitor = false;
 
+    /* tuning options */
+    param->threshold = FIFO_THRESHOLD_SIZE;
+
     /* statistics */
     param->b_summary = false;
     param->summary.mode = SUM_BANDWIDTH;
@@ -204,15 +232,15 @@ static void params_free(params_t *param)
 static void dvbinfo_close(params_t *param)
 {
 #ifdef HAVE_SYS_SOCKET_H
-    if (param->input && param->b_udp)
+    if (param->input && param->b_udp && (param->fd_in >= 0))
         udp_close(param->fd_in);
-    else if (param->input && param->b_tcp)
+    else if (param->input && param->b_tcp && (param->fd_in >= 0))
         tcp_close(param->fd_in);
     else
 #endif
-    if (param->input)
+    if (param->input && (param->fd_in >= 0))
         close(param->fd_in);
-    if (param->output)
+    if (param->output && (param->fd_out >= 0))
         close(param->fd_out);
 }
 
@@ -288,7 +316,7 @@ static void *dvbinfo_capture(void *data)
         buffer->i_date = mdate();
 
         /* check fifo size */
-        if (fifo_size(capture->fifo) >= FIFO_THRESHOLD_SIZE)
+        if (fifo_size(capture->fifo) >= param->threshold)
         {
             pthread_mutex_lock(&capture->lock);
             capture->b_fifo_full = true;
@@ -305,7 +333,7 @@ static void *dvbinfo_capture(void *data)
             else
             {
                 libdvbpsi_log(capture->params, DVBINFO_LOG_ERROR,
-                          "error fifo full discarding buffer");
+                          "error fifo full discarding buffer\n");
                 fifo_push(capture->empty, buffer);
                 continue;
             }
@@ -358,17 +386,17 @@ static int dvbinfo_process(dvbinfo_capture_t *capture)
 
         if (param->output)
         {
-            size_t size = param->pf_write(param->fd_out, buffer->p_data, buffer->i_size);
+            ssize_t size = param->pf_write(param->fd_out, buffer->p_data, buffer->i_size);
             if (size < 0) /* error writing */
             {
                 libdvbpsi_log(param, DVBINFO_LOG_ERROR,
-                              "error (%d) writting to %s", errno, param->output);
+                              "error (%d) writting to %s\n", errno, param->output);
                 break;
             }
-            else if (size < buffer->i_size) /* short writting disk full? */
+            else if ((size_t)size < buffer->i_size) /* short writting disk full? */
             {
                 libdvbpsi_log(param, DVBINFO_LOG_ERROR,
-                              "error writting to %s (disk full?)", param->output);
+                              "error writting to %s (disk full?)\n", param->output);
                 break;
             }
         }
@@ -388,7 +416,13 @@ static int dvbinfo_process(dvbinfo_capture_t *capture)
                     fflush(fd);
                     fclose(fd);
                     unlink(param->summary.file);
-                    rename(psz_temp, param->summary.file);
+                    int ret = rename(psz_temp, param->summary.file);
+                    if (ret < 0)
+                    {
+                        libdvbpsi_log(param, DVBINFO_LOG_ERROR,
+                                      "failed renming summary file (disabling summary logging)\n");
+                        param->b_summary = false;
+                    }
                 }
                 else
                 {
@@ -405,7 +439,7 @@ static int dvbinfo_process(dvbinfo_capture_t *capture)
         buffer = NULL;
 
         /* check fifo size */
-        if (fifo_size(capture->fifo) < FIFO_THRESHOLD_SIZE)
+        if (fifo_size(capture->fifo) < param->threshold)
         {
             pthread_mutex_lock(&capture->lock);
             capture->b_fifo_full = false;
@@ -436,7 +470,7 @@ int main(int argc, char **pp_argv)
     params_t *param = NULL;
     char c;
 
-    printf("dvbinfo: Copyright (C) 2011-2012 M2X BV\n");
+    printf("dvbinfo: Copyright (C) 2011-2014 M2X BV\n");
     printf("License: LGPL v2.1\n");
 
     if (argc == 1)
@@ -474,11 +508,13 @@ int main(int argc, char **pp_argv)
         { "summary",        required_argument, NULL, 's' },
         { "summary-file",   required_argument, NULL, 'j' },
         { "summary-period", required_argument, NULL, 'p' },
+        /* - tuning options - */
+        { "capturesize",    required_argument, NULL, 'c' },
 #endif
         { NULL, 0, NULL, 0 }
     };
 #ifdef HAVE_SYS_SOCKET_H
-    while ((c = getopt_long(argc, pp_argv, "a:d:f:i:ho:ms:tu", long_options, NULL)) != -1)
+    while ((c = getopt_long(argc, pp_argv, "a:c:d:f:i:j:ho:p:ms:tu", long_options, NULL)) != -1)
 #else
     while ((c = getopt_long(argc, pp_argv, "d:f:h", long_options, NULL)) != -1)
 #endif
@@ -515,7 +551,6 @@ int main(int argc, char **pp_argv)
 
 #ifdef HAVE_SYS_SOCKET_H
             case 'a':
-            {
                 if (optarg)
                 {
                     if (asprintf(&param->mcast_interface, "%s", optarg) < 0)
@@ -524,7 +559,8 @@ int main(int argc, char **pp_argv)
                         usage();
                     }
                 }
-            }
+                break;
+
             case 'i':
                 if (optarg)
                 {
@@ -571,20 +607,44 @@ int main(int argc, char **pp_argv)
                 param->pf_read = udp_read;
                 break;
 
+            /* - tuning options - */
+            case 'c':
+                if (optarg)
+                {
+                    param->threshold = strtoul(optarg, NULL, 10);
+                    if (((errno == ERANGE) && (param->threshold == ULONG_MAX)) ||
+                        ((errno != 0) && (param->threshold == 0)))
+                    {
+                        fprintf(stderr, "Option --capturesize has invalid content %s\n", optarg);
+                        params_free(param);
+                        usage();
+                    }
+                }
+                break;
+
             /* - Statistics */
             case 's':
             {
-                param->b_summary = true;
-                ssize_t size = ARRAY_SIZE(psz_summary_mode);
-                for (ssize_t i = 0; i < size; i++)
+                if (optarg)
                 {
-                    printf("summary mode %s\n", psz_summary_mode[i]);
-                    if (strncmp(optarg, psz_summary_mode[i], strlen(psz_summary_mode[i])) == 0)
+                    ssize_t size = ARRAY_SIZE(psz_summary_mode);
+                    for (ssize_t i = 0; i < size; i++)
                     {
-                        param->summary.mode = i_summary_mode[i];
-                        break;
+                        printf("summary mode %s\n", psz_summary_mode[i]);
+                        if (strncmp(optarg, psz_summary_mode[i], strlen(psz_summary_mode[i])) == 0)
+                        {
+                            param->summary.mode = i_summary_mode[i];
+                            param->b_summary = true;
+                            break;
+                        }
                     }
                 }
+                if (!param->b_summary)
+                {
+                    fprintf(stderr, "Option --summary has invalid content %s\n", optarg);
+                    params_free(param);
+                    usage();
+                }
                 break;
             }
             case 'j':
@@ -599,9 +659,9 @@ int main(int argc, char **pp_argv)
                 break;
 
             case 'p':
+                if (optarg)
                 {
-                    char *end = NULL;
-                    param->summary.period = strtoll(optarg, &end, 10);
+                    param->summary.period = strtoll(optarg, NULL, 10);
                     if (((errno == ERANGE) &&
                             ((param->summary.period == LLONG_MIN) ||
                              (param->summary.period == LLONG_MAX))) ||
