@@ -247,7 +247,7 @@ int udp_open(const char *interface, const char *ipaddress, int port)
         sflags = SOCK_CLOEXEC;
 #endif
         s_ctl = socket(ptr->ai_family, ptr->ai_socktype | sflags, ptr->ai_protocol);
-        if (s_ctl <= 0)
+        if (s_ctl < 0)
         {
             perror("udp socket error");
             continue;
@@ -257,23 +257,29 @@ int udp_open(const char *interface, const char *ipaddress, int port)
         if (!set_fdsocketclosexec(s_ctl))
         {
             close(s_ctl);
+            s_ctl = -1;
             continue;
         }
 #endif
 
         /* Increase the receive buffer size to 1/2MB (8Mb/s during 1/2s)
          * to avoid packet loss caused in case of scheduling hiccups */
-        setsockopt (s_ctl, SOL_SOCKET, SO_RCVBUF,
-                    (void *)&(int){ 0x80000 }, sizeof (int));
-        setsockopt (s_ctl, SOL_SOCKET, SO_SNDBUF,
-                    (void *)&(int){ 0x80000 }, sizeof (int));
+        if (setsockopt (s_ctl, SOL_SOCKET, SO_RCVBUF,
+                    (void *)&(int){ 0x80000 }, sizeof (int)) < 0)
+            perror("udp setsockopt error");
 
-        setsockopt (s_ctl, SOL_SOCKET, SO_REUSEADDR, &(int){ 1 }, sizeof (int));
+        if (setsockopt (s_ctl, SOL_SOCKET, SO_SNDBUF,
+                    (void *)&(int){ 0x80000 }, sizeof (int)) < 0)
+            perror("udp setsockopt error");
+
+        if (setsockopt (s_ctl, SOL_SOCKET, SO_REUSEADDR, &(int){ 1 }, sizeof (int)) < 0)
+            perror("udp setsockopt error");
 
         result = bind(s_ctl, ptr->ai_addr, ptr->ai_addrlen);
         if (result < 0)
         {
             close(s_ctl);
+            s_ctl = -1;
             perror("udp bind error");
             continue;
         }
@@ -283,6 +289,7 @@ int udp_open(const char *interface, const char *ipaddress, int port)
             mcast_connect(s_ctl, NULL, saddr, ptr->ai_addrlen))
         {
             close(s_ctl);
+            s_ctl = -1;
             perror("mcast connect error");
             continue;
         }
